Package: distory
Version: 1.4.5
Date: 2024-10-07
Title: Distance Between Phylogenetic Histories
Authors@R: c(person(given = "John", family = "Chakerian", role = c("aut")),
   person(given = "Susan", family = "Holmes", role = c("aut")),
   person(given = "Emmanuel", family = "Paradis", role = "cre",
          email = "Emmanuel.Paradis@ird.fr"))
Depends: ape (>= 5.0)
Imports: graphics, stats
Description: Geodesic distance between phylogenetic trees and
  associated functions. The theoretical background of 'distory'
  is published in Billera et al. (2001) "Geometry of the space of
  phylogenetic trees." <doi:10.1006/aama.2001.0759>.
License: BSD_3_clause + file LICENSE
NeedsCompilation: yes
Packaged: 2024-10-07 19:48:04 UTC; paradis
Author: John Chakerian [aut],
  Susan Holmes [aut],
  Emmanuel Paradis [cre]
Maintainer: Emmanuel Paradis <Emmanuel.Paradis@ird.fr>
Repository: CRAN
Date/Publication: 2024-10-07 21:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 00:25:58 UTC; unix
Archs: distory.so.dSYM
